#! Flux2D 12.1
lastInstance = ApplicationMagneticACThermal2D(frequency='50',
                                              domain2D=Domain2DAxisymetric(),
                                              temperatureUnit=Unit['CELSIUS_DEGREE'],
                                              coilCoefficient=CoilCoefficientAutomatic(),
                                              transientInitialization=TransientInitializationZeroInitialSolution())
VariationParameterFormula(name='ABS_OUTER_TUBE',

                          formula='0.2')


VariationParameterFormula(name='ABS_INNER_TUBE',

                          formula='0.8')


VariationParameterFormula(name='EMIS_OUTER_TUBE',

                          formula='0.8')


VariationParameterFormula(name='CONV_INNER_TUBE',

                          formula='100')


VariationParameterFormula(name='EMIS_INNER_TUBE',

                          formula='0')

Material(name='STEEL',

         propertyBH=PropertyBhNonlinearJmuknee(initialMur='600',

         js='2',

         knee='0.4',

         equivalentHarmonicCurve=EquivalentBhUnmodified()),

         propertyJE=PropertyJeLinear(rho='0.25E-6'),

         thermalConductivity=KtIsotropic(k='47'),

         specificHeat=RhoCpConstant(rhoCp='.39E+7'))


Material(name='COPPER',

         propertyBH=PropertyBhLinear(mur='1'),

         propertyJE=PropertyJeLinear(rho='2E-8'))


Material(name='INOX_316',

         propertyBH=PropertyBhLinear(mur='1'),

         propertyJE=PropertyJeLinear(rho='7.4E-7'),

         thermalConductivity=KtIsotropic(k='16.3'),

         specificHeat=RhoCpConstant(rhoCp='3995920.0'),

         volumicMass='7960.0')
RegionLine(name='CONVECTION',

           magneticACThermal2D=MagneticACThermal2DLine(thermalType=Thermal2DLineThermalExchange(convection=Convection_surf_i(coefficient=coef_convection_i_uniforme(parameter='CONV_INNER_TUBE'),

           infiniteTemperature=ioTemperature(temperature='20.0',

           unit=Unit['CELSIUS_DEGREE']))),

           magneticType=MagneticAC2DLineInactive()),

           color=Color['Green'],

           visibility=Visibility['VISIBLE'])

RegionLine(name='RADIATION_STEEL',

           magneticACThermal2D=MagneticACThermal2DLine(thermalType=Thermal2DLineThermalExchange(radiation=localRadiation(coefficients=coef_rayonnement_i_uniforme(emissivity='EMIS_OUTER_TUBE',

           absorption='ABS_OUTER_TUBE'))),

           magneticType=MagneticAC2DLineInactive()),

           color=Color['Red'],

           visibility=Visibility['VISIBLE'])


RegionLine(name='RADIATION_INOX',

           magneticACThermal2D=MagneticACThermal2DLine(thermalType=Thermal2DLineThermalExchange(radiation=localRadiation(coefficients=coef_rayonnement_i_uniforme(emissivity='EMIS_INNER_TUBE',

           absorption='ABS_INNER_TUBE'))),

           magneticType=MagneticAC2DLineInactive()),

           color=Color['Red'],

           visibility=Visibility['VISIBLE'])



RegionFace(name='AIR',

           magneticACThermal2D=MagneticACThermal2DFace(thermalType=Thermal2DFaceInactive(transparency='automatic'),

           magneticType=MagneticAC2DFaceVacuum()),

           color=Color['Turquoise'],

           visibility=Visibility['VISIBLE'])

CurrentStrandedCoil(name='COIL_COMPONENT',

                    rmsModulus='15',

                    phase='0.0')

RegionFace(name='COIL',

           magneticACThermal2D=MagneticACThermal2DFace(thermalType=Thermal2DFaceInactive(transparency='automatic'),

           magneticType=MagneticAC2DFaceCoilConductor(coilConductor=CoilConductor2DPositive(turnNumber='500',

           seriesParallel=AllInSeries(),

           electricComponent=CoilConductor['COIL_COMPONENT'],

           fillFactor='1.0')),

           material=Material['COPPER']),

           color=Color['Red'],

           visibility=Visibility['VISIBLE'])




RegionFace(name='OUTER_TUBE',

           magneticACThermal2D=MagneticACThermal2DFace(thermalType=Thermal2DFaceThermalConductor(transparency='automatic',

           heat=VolumeHeatSourceJouleEffectValue()),

           magneticType=MagneticAC2DFaceSolidConductor(circuitType=NoCircuit()),

           material=Material['STEEL']),

           color=Color['Green'],

           visibility=Visibility['VISIBLE'])


RegionFace(name='INNER_TUBE',

           magneticACThermal2D=MagneticACThermal2DFace(thermalType=Thermal2DFaceThermalConductor(transparency='automatic'),

           magneticType=MagneticAC2DFaceMagnetic(),

           material=Material['INOX_316']),

           color=Color['Yellow'],

           visibility=Visibility['VISIBLE'])


LineExtruded[8, 21].region = RegionLine['CONVECTION']



LineExtruded[12, 25].region = RegionLine['RADIATION_STEEL']


LineExtruded[10, 23].region = RegionLine['RADIATION_INOX']


Face[1, 7, 3, 9, 5, 11, 13].region = RegionFace['AIR']


FaceStructured[6, 12].region = RegionFace['COIL']


FaceStructured[4, 10].region = RegionFace['OUTER_TUBE']


FaceStructured[2, 8].region = RegionFace['INNER_TUBE']

RegionFace['INFINITE'].magneticACThermal2D = MagneticACThermal2DFace(thermalType=Thermal2DFaceInactive(transparency='automatic'),
                                                                     magneticType=MagneticAC2DFaceVacuum())


saveProjectAs('physbuilt.FLU')



